CI_CODEASTER="${HOME}/.ci_codeaster"
CACHE_REPO="${CI_CODEASTER}/repos"
LOG="${CI_CODEASTER}/log"
URLREFE=http://aster-repo.der.edf.fr/scm/hg/codeaster

_error()
{
    # usage: _error messsage [unlock]
    [ $# -gt 1 ] && [ "${2}" = "unlock" ] && unlock_all
    echo "ERROR: ${1}"
    echo
    usage
}

_init_log()
{
    # usage: _init_log name
    mkdir -p "${LOG}"
    echo "${LOG}/${1}.log"
}

_limit_log()
{
    # usage: _limit_log logfile [size=50Mb]
    local log="${1}"
    local size=50000000
    [ ! -f "${log}" ] && return
    [ $# -gt 1 ] && size="${2}"
    tail -c ${size} "${log}" > "${log}.tmp"
    mv "${log}.tmp" "${log}"
}

_pushd()
{
    pushd "${1}" > /dev/null
}

_popd()
{
    popd > /dev/null
}

lock_repo()
{
    # usage: lock_repo repo
    # lock a repository during using it (update)
    local repo=${1}
    local lock="${CACHE_REPO}/.lock_${repo}"
    for i in {1..30}; do
        if [ ! -f "${lock}" ]; then
            echo "locked by ${0} ($$) - $(date)" > "${lock}"
            return 0
        else
            echo "${repo} is locked, waiting 20 secs..."
            sleep 20
        fi
    done
    _error "${repo} locked by another process, timeout (10 min)"
}

unlock_repo()
{
    # usage: lock_repo repo
    # lock a repository during using it (update)
    local lock="${CACHE_REPO}/.lock_${1}"
    rm -f "${lock}"
}

unlock_all()
{
    for repo in devtools data src validation; do
        unlock_repo ${repo}
    done
}

run_tests()
{
    # usage: run_tests installdir rerun [options]
    local installdir="${1}"
    local rerun="${2}"
    declare -a opts="${@:2}"

    _pushd ${installdir}/bin
    ./run_ctest "${opts[@]}" --clean
    iret=${?}
    if [ ${iret} -ne 0 ] && [ "${rerun}" = "true" ]; then
        ./run_ctest "${opts[@]}" --rerun-failed
    fi
    _popd
}
