#!/usr/bin/env python3
# coding: utf-8

"""
    send_cr_eda.py [options] REPORT

Send the EDA meeting report file to the EDA mailing list.

"""

import argparse
import os
import re

from aslint.config import ASCFG
from aslint.i18n import _
from aslint.logger import logger, setlevel
from hgaster.ext_utils import sendmail

TEXT = """
Bonjour,

{text}

Cordialement,
"""


def get_subject_from(fname):
    """Return the subject from the report filename"""
    reg = re.compile("e(?P<year>[0-9]{4})(?P<month>[0-9]{2})(?P<day>[0-9]{2})"
                     ".pdf$")
    mat = reg.search(fname)
    subject = "Compte-rendu de l'EDA"
    text = "Veuillez trouver ci-joint le dernier compte-rendu de l'EDA."
    if mat:
        date = "{day}/{month}/{year}".format(**mat.groupdict())
        subject = "Compte-rendu de l'EDA du " + date
        text = ("Veuillez trouver ci-joint le compte-rendu de l'EDA du {0}."
                .format(date))
    return subject, TEXT.format(text=text)


if __name__ == '__main__':
    # command arguments parser
    parser = argparse.ArgumentParser(
        usage=__doc__,
        formatter_class=argparse.ArgumentDefaultsHelpFormatter)
    parser.add_argument('-g', '--debug', action="store_true",
                        help="add debug informations")
    parser.add_argument('--to', action='store',
                        help="destination address "
                             "(default: aster-eda mailing list)")
    parser.add_argument('-n', '--dry-run', action='store_true',
                        help="do not send the email")
    parser.add_argument('report', metavar='REPORT', nargs="+",
                        help="Filename(s) of the report")
    args = parser.parse_args()
    if args.debug:
        setlevel()
    subject, text = get_subject_from(args.report[0])

    dest = args.to or ASCFG.get('notify.eda')
    if args.dry_run:
        logger.info(_("Send email to {0}").format(dest))
        logger.info(_("Subject: {0}").format(subject))
        logger.info(_("Message:\n{0}").format(text))
        logger.info(_("Attached files: {0}").format(args.report))
    else:
        sendmail(dest, subject, text,
                fromaddr=ASCFG.get('notify.codeaster'),
                add_html=True,
                attach=args.report,
                footer=False)
