# coding=utf-8

"""Decorators"""

from functools import wraps

from aslint.logger import logger


def interrupt_decorator(func):
    """Pass KeyboardInterrupt to be catched by the multiprocessing Pool"""
    @wraps(func)
    def wrapper(*args, **kwds):
        """wrapper"""
        try:
            return func(*args, **kwds)
        except KeyboardInterrupt as exc:
            if logger.debug_enabled():
                raise
            raise RuntimeError(exc)
    return wrapper


def stop_on_failure(method):
    """decorator to highlight the execution of a method and check its error code
    The instance must have a _check_error method."""
    @wraps(method)
    def wrapper(inst, *args, **kwds):
        """wrapper"""
        logger.add_cr()
        logger.debug('--- begin %s ---', method.__name__)
        errcode = method(inst, *args, **kwds)
        logger.debug('---  end  %s ---', method.__name__)
        logger.update_errcode(errcode)
        inst._check_error()
        return errcode
    return wrapper


def log_as_important(func):
    """decorator to mark messages as important during execution"""
    @wraps(func)
    def wrapper(*args, **kwds):
        """wrapper"""
        logger.start_important()
        results = func(*args, **kwds)
        logger.add_cr()
        logger.stop_important()
        return results
    return wrapper
