# coding=utf-8

"""
Tests for mercurial API.
"""

import os.path as osp
import unittest

from hamcrest import *
from mercurial_api import hg, ui as UI
from mercurial_api.utils import hgcmd, is_repository, shell_cmd
from testutils import silent_logger


def test_hg():
    repo = hg.Repository(".")
    assert_that(repo.root, equal_to(osp.abspath(".")))

    current = repo['tip']
    assert_that(current.rev(), instance_of(int))
    assert_that(current.hex(), instance_of(str))
    assert_that(str(current), equal_to(current.hex()))
    assert_that(int(current.hex(), 16), instance_of(int))
    assert_that(current.phase(), is_in(["secret", "draft", "public"]))
    assert_that(current.user(), instance_of(str))
    assert_that(current.description(), instance_of(str))
    assert_that(current.branch(), instance_of(str))

    same = repo['tip']
    assert_that(current == same, equal_to(True))
    assert_that(current != same, equal_to(False))

    parent = current.ancestor(same)
    assert_that(current == parent, equal_to(True))

    assert_that(current.children(), empty())

    assert_that(calling(hg.Repository).with_args("xx"),
                raises(IOError))

    repo = hg.repository("fake ui", ".")
    assert_that(repo.root, equal_to(osp.abspath(".")))

    ui = UI.ui()
    # hope 'username' is defined and contains an email address!
    assert_that("@" , is_in(ui.config("ui", "username")))
    assert_that(ui.configbool("ui", "unknown_option"), equal_to(False))
    assert_that(calling(ui.configbool).with_args("ui", "username"),
                raises(ValueError))


def test_utils():
    assert_that(is_repository('.'), equal_to(True))
    iret = hgcmd(('status', ), '.')[0]
    assert_that(iret, equal_to(0))
    iret = shell_cmd('.', 'status')[0]
    assert_that(iret, equal_to(0))
    iret = shell_cmd('.', ('status', ))[0]
    assert_that(iret, equal_to(0))


if __name__ == "__main__":
    import sys
    from testutils import get_test_suite
    RET = unittest.TextTestRunner(verbosity=2).run(get_test_suite(__name__))
    sys.exit(not RET.wasSuccessful())
